@@ -49,11 +49,11 @@ private:
 
     bool parse( const QVariant& data );
     bool parse( const QByteArray& data );
-private slots:
+private Q_SLOTS:
     void parseData();
     void error( QNetworkReply::NetworkError error );
 };
 
 }
 
-#endif //ADDREMOVERESULT_PRIVATE_H
\ No newline at end of file
+#endif //ADDREMOVERESULT_PRIVATE_H
