@@ -1,6 +1,6 @@
 /***************************************************************************
 * This file is part of libmygpo-qt                                         *
-* Copyright (c) 2010 - 2011 Stefan Derkits <stefan@derkits.at>             *
+* Copyright (c) 2010 - 2014 Stefan Derkits <stefan@derkits.at>             *
 * Copyright (c) 2010 - 2011 Christian Wagner <christian.wagner86@gmx.at>   *
 * Copyright (c) 2010 - 2011 Felix Winter <ixos01@gmail.com>                *
 *                                                                          *
@@ -23,10 +23,6 @@
 #ifndef LIBMYGPO_QT_APIREQUEST_H
 #define LIBMYGPO_QT_APIREQUEST_H
 
-#define MYGPO_MAJOR_VERSION 1
-#define MYGPO_MINOR_VERSION 0
-#define MYGPO_PATCH_VERSION 5
-
 #include "mygpo_export.h"
 #include "AddRemoveResult.h"
 #include "EpisodeList.h"
@@ -60,9 +56,9 @@ public:
     ApiRequest( const QString& username, const QString& password, QNetworkAccessManager* nam );
     ApiRequest( QNetworkAccessManager* nam );
     ~ApiRequest( );
-    
+
     //SIMPLE API
-    
+
     /**
      * Returns the OPML Result for the Simple API Call "Downloading Podcast Toplists"
      * @param count The number of Podcasts that should be returned - will be set to to 100 if > 100 or < 1
@@ -87,8 +83,8 @@ public:
      *
      */
     QNetworkReply* suggestionsOpml( uint count );
-    
-    QNetworkReply* downloadSubscriptionsOpml( const QString& username, const QString& device );
+
+    QNetworkReply* downloadSubscriptionsOpml( const QString& username, const QString& device = QString() );
 
     /**
      * Returns the TXT Result for the Simple API Call "Downloading Podcast Toplists"
@@ -114,8 +110,8 @@ public:
      *
      */
     QNetworkReply* suggestionsTxt( uint count );
-    
-    QNetworkReply* downloadSubscriptionsTxt( const QString& username, const QString& device );
+
+    QNetworkReply* downloadSubscriptionsTxt( const QString& username, const QString& device = QString() );
 
     /**
      * Returns the TXT Result for the Simple API Call "Downloading Podcast Toplists"
@@ -157,9 +153,9 @@ public:
      *
      */
     PodcastListPtr suggestions( uint count );
-    
-    QNetworkReply* downloadSubscriptionsJson( const QString& username, const QString& device );
-    
+
+    QNetworkReply* downloadSubscriptionsJson( const QString& username, const QString& device = QString() );
+
     //ADVANCED API
 
     /**
