@@ -1,6 +1,6 @@
 /***************************************************************************
 * This file is part of libmygpo-qt                                         *
-* Copyright (c) 2010 - 2011 Stefan Derkits <stefan@derkits.at>             *
+* Copyright (c) 2010 - 2013 Stefan Derkits <stefan@derkits.at>             *
 * Copyright (c) 2010 - 2011 Christian Wagner <christian.wagner86@gmx.at>   *
 * Copyright (c) 2010 - 2011 Felix Winter <ixos01@gmail.com>                *
 *                                                                          *
@@ -20,8 +20,8 @@
 * USA                                                                      *
 ***************************************************************************/
 
-#ifndef EPISODEACTIONLIST_H
-#define EPISODEACTIONLIST_H
+#ifndef LIBMYGPO_QT_EPISODEACTIONLIST_H
+#define LIBMYGPO_QT_EPISODEACTIONLIST_H
 
 #include "EpisodeAction.h"
 #include "mygpo_export.h"
@@ -52,7 +52,7 @@ public:
 private:
     EpisodeActionListPrivate* const d;
     friend class EpisodeActionListPrivate;
-signals:
+Q_SIGNALS:
     /**Gets emitted when the data is ready to read*/
     void finished();
     /**Gets emitted when an parse error ocurred*/
@@ -68,4 +68,4 @@ typedef QSharedPointer<EpisodeActionList> EpisodeActionListPtr;
 
 Q_DECLARE_METATYPE( mygpo::EpisodeActionListPtr );
 
-#endif // EPISODEACTIONLIST_H
+#endif // LIBMYGPO_QT_EPISODEACTIONLIST_H
