@@ -1,6 +1,6 @@
 /***************************************************************************
 * This file is part of libmygpo-qt                                         *
-* Copyright (c) 2010 - 2011 Stefan Derkits <stefan@derkits.at>             *
+* Copyright (c) 2010 - 2013 Stefan Derkits <stefan@derkits.at>             *
 * Copyright (c) 2010 - 2011 Christian Wagner <christian.wagner86@gmx.at>   *
 * Copyright (c) 2010 - 2011 Felix Winter <ixos01@gmail.com>                *
 *                                                                          *
@@ -20,8 +20,8 @@
 * USA                                                                      *
 ***************************************************************************/
 
-#ifndef TAGLIST_H
-#define TAGLIST_H
+#ifndef LIBMYGPO_QT_TAGLIST_H
+#define LIBMYGPO_QT_TAGLIST_H
 
 #include "Tag.h"
 #include "mygpo_export.h"
@@ -48,7 +48,7 @@ private:
     Q_DISABLE_COPY( TagList )
     TagListPrivate* const d;
     friend class TagListPrivate;
-signals:
+Q_SIGNALS:
     /**Gets emitted when the data is ready to read*/
     void finished();
     /**Gets emitted when an parse error ocurred*/
@@ -63,4 +63,4 @@ typedef QSharedPointer<TagList> TagListPtr;
 
 Q_DECLARE_METATYPE( mygpo::TagListPtr );
 
-#endif // TAGLIST_H
+#endif // LIBMYGPO_QT_TAGLIST_H
