@@ -46,7 +46,7 @@ private:
 
     bool parse( const QVariant& data );
     bool parse( const QByteArray& data );
-private slots:
+private Q_SLOTS:
     void parseData();
     void error( QNetworkReply::NetworkError error );
 };
